/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -a repositoryadaptor -i repository.h -l Repository /usr/src/ports/cervisia/cervisia-17.08.3-1.x86_64/src/cervisia-17.08.3/cvsservice/org.kde.cervisia5.repository.xml
 *
 * qdbusxml2cpp is Copyright (C) 2017 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "repositoryadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class RepositoryAdaptor
 */

RepositoryAdaptor::RepositoryAdaptor(Repository *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

RepositoryAdaptor::~RepositoryAdaptor()
{
    // destructor
}

QString RepositoryAdaptor::clientOnly()
{
    // handle method call org.kde.cervisia5.repository.clientOnly
    return parent()->clientOnly();
}

QString RepositoryAdaptor::cvsClient()
{
    // handle method call org.kde.cervisia5.repository.cvsClient
    return parent()->cvsClient();
}

QString RepositoryAdaptor::location()
{
    // handle method call org.kde.cervisia5.repository.location
    return parent()->location();
}

bool RepositoryAdaptor::retrieveCvsignoreFile()
{
    // handle method call org.kde.cervisia5.repository.retrieveCvsignoreFile
    return parent()->retrieveCvsignoreFile();
}

QString RepositoryAdaptor::rsh()
{
    // handle method call org.kde.cervisia5.repository.rsh
    return parent()->rsh();
}

QString RepositoryAdaptor::server()
{
    // handle method call org.kde.cervisia5.repository.server
    return parent()->server();
}

bool RepositoryAdaptor::setWorkingCopy(const QString &dirName)
{
    // handle method call org.kde.cervisia5.repository.setWorkingCopy
    return parent()->setWorkingCopy(dirName);
}

QString RepositoryAdaptor::workingCopy()
{
    // handle method call org.kde.cervisia5.repository.workingCopy
    return parent()->workingCopy();
}


#include "repositoryadaptor.moc"
