/****************************************************************************
** Meta object code from reading C++ file 'updateview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/cervisia-17.08.3/updateview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'updateview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_UpdateView_t {
    QByteArrayData data[17];
    char stringdata0[188];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_UpdateView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_UpdateView_t qt_meta_stringdata_UpdateView = {
    {
QT_MOC_LITERAL(0, 0, 10), // "UpdateView"
QT_MOC_LITERAL(1, 11, 10), // "fileOpened"
QT_MOC_LITERAL(2, 22, 0), // ""
QT_MOC_LITERAL(3, 23, 8), // "filename"
QT_MOC_LITERAL(4, 32, 21), // "unfoldSelectedFolders"
QT_MOC_LITERAL(5, 54, 10), // "unfoldTree"
QT_MOC_LITERAL(6, 65, 8), // "foldTree"
QT_MOC_LITERAL(7, 74, 9), // "finishJob"
QT_MOC_LITERAL(8, 84, 10), // "normalExit"
QT_MOC_LITERAL(9, 95, 10), // "exitStatus"
QT_MOC_LITERAL(10, 106, 17), // "processUpdateLine"
QT_MOC_LITERAL(11, 124, 4), // "line"
QT_MOC_LITERAL(12, 129, 12), // "itemExecuted"
QT_MOC_LITERAL(13, 142, 16), // "QTreeWidgetItem*"
QT_MOC_LITERAL(14, 159, 4), // "item"
QT_MOC_LITERAL(15, 164, 6), // "column"
QT_MOC_LITERAL(16, 171, 16) // "itemExpandedSlot"

    },
    "UpdateView\0fileOpened\0\0filename\0"
    "unfoldSelectedFolders\0unfoldTree\0"
    "foldTree\0finishJob\0normalExit\0exitStatus\0"
    "processUpdateLine\0line\0itemExecuted\0"
    "QTreeWidgetItem*\0item\0column\0"
    "itemExpandedSlot"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_UpdateView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   54,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    0,   57,    2, 0x0a /* Public */,
       5,    0,   58,    2, 0x0a /* Public */,
       6,    0,   59,    2, 0x0a /* Public */,
       7,    2,   60,    2, 0x0a /* Public */,
      10,    1,   65,    2, 0x0a /* Public */,
      12,    2,   68,    2, 0x08 /* Private */,
      16,    1,   73,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool, QMetaType::Int,    8,    9,
    QMetaType::Void, QMetaType::QString,   11,
    QMetaType::Void, 0x80000000 | 13, QMetaType::Int,   14,   15,
    QMetaType::Void, 0x80000000 | 13,   14,

       0        // eod
};

void UpdateView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        UpdateView *_t = static_cast<UpdateView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->fileOpened((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 1: _t->unfoldSelectedFolders(); break;
        case 2: _t->unfoldTree(); break;
        case 3: _t->foldTree(); break;
        case 4: _t->finishJob((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 5: _t->processUpdateLine((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 6: _t->itemExecuted((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 7: _t->itemExpandedSlot((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (UpdateView::*_t)(QString );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&UpdateView::fileOpened)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject UpdateView::staticMetaObject = {
    { &QTreeWidget::staticMetaObject, qt_meta_stringdata_UpdateView.data,
      qt_meta_data_UpdateView,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *UpdateView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UpdateView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_UpdateView.stringdata0))
        return static_cast<void*>(this);
    return QTreeWidget::qt_metacast(_clname);
}

int UpdateView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void UpdateView::fileOpened(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
