/****************************************************************************
** Meta object code from reading C++ file 'tooltip.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/cervisia-17.08.3/tooltip.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tooltip.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Cervisia__ToolTip_t {
    QByteArrayData data[8];
    char stringdata0[62];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Cervisia__ToolTip_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Cervisia__ToolTip_t qt_meta_stringdata_Cervisia__ToolTip = {
    {
QT_MOC_LITERAL(0, 0, 17), // "Cervisia::ToolTip"
QT_MOC_LITERAL(1, 18, 12), // "queryToolTip"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 3), // "pos"
QT_MOC_LITERAL(4, 36, 6), // "QRect&"
QT_MOC_LITERAL(5, 43, 4), // "rect"
QT_MOC_LITERAL(6, 48, 8), // "QString&"
QT_MOC_LITERAL(7, 57, 4) // "text"

    },
    "Cervisia::ToolTip\0queryToolTip\0\0pos\0"
    "QRect&\0rect\0QString&\0text"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Cervisia__ToolTip[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    3,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QPoint, 0x80000000 | 4, 0x80000000 | 6,    3,    5,    7,

       0        // eod
};

void Cervisia::ToolTip::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ToolTip *_t = static_cast<ToolTip *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->queryToolTip((*reinterpret_cast< const QPoint(*)>(_a[1])),(*reinterpret_cast< QRect(*)>(_a[2])),(*reinterpret_cast< QString(*)>(_a[3]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (ToolTip::*_t)(const QPoint & , QRect & , QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ToolTip::queryToolTip)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject Cervisia::ToolTip::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Cervisia__ToolTip.data,
      qt_meta_data_Cervisia__ToolTip,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Cervisia::ToolTip::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Cervisia::ToolTip::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Cervisia__ToolTip.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Cervisia::ToolTip::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void Cervisia::ToolTip::queryToolTip(const QPoint & _t1, QRect & _t2, QString & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
