/****************************************************************************
** Meta object code from reading C++ file 'cvsservice.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/cervisia-17.08.3/cvsservice/cvsservice.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'cvsservice.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_CvsService_t {
    QByteArrayData data[67];
    char stringdata0[616];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CvsService_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CvsService_t qt_meta_stringdata_CvsService = {
    {
QT_MOC_LITERAL(0, 0, 10), // "CvsService"
QT_MOC_LITERAL(1, 11, 3), // "add"
QT_MOC_LITERAL(2, 15, 15), // "QDBusObjectPath"
QT_MOC_LITERAL(3, 31, 0), // ""
QT_MOC_LITERAL(4, 32, 5), // "files"
QT_MOC_LITERAL(5, 38, 8), // "isBinary"
QT_MOC_LITERAL(6, 47, 8), // "addWatch"
QT_MOC_LITERAL(7, 56, 6), // "events"
QT_MOC_LITERAL(8, 63, 8), // "annotate"
QT_MOC_LITERAL(9, 72, 8), // "fileName"
QT_MOC_LITERAL(10, 81, 8), // "revision"
QT_MOC_LITERAL(11, 90, 8), // "checkout"
QT_MOC_LITERAL(12, 99, 10), // "workingDir"
QT_MOC_LITERAL(13, 110, 10), // "repository"
QT_MOC_LITERAL(14, 121, 6), // "module"
QT_MOC_LITERAL(15, 128, 3), // "tag"
QT_MOC_LITERAL(16, 132, 9), // "pruneDirs"
QT_MOC_LITERAL(17, 142, 5), // "alias"
QT_MOC_LITERAL(18, 148, 10), // "exportOnly"
QT_MOC_LITERAL(19, 159, 9), // "recursive"
QT_MOC_LITERAL(20, 169, 6), // "commit"
QT_MOC_LITERAL(21, 176, 13), // "commitMessage"
QT_MOC_LITERAL(22, 190, 16), // "createRepository"
QT_MOC_LITERAL(23, 207, 9), // "createTag"
QT_MOC_LITERAL(24, 217, 6), // "branch"
QT_MOC_LITERAL(25, 224, 5), // "force"
QT_MOC_LITERAL(26, 230, 9), // "deleteTag"
QT_MOC_LITERAL(27, 240, 21), // "downloadCvsIgnoreFile"
QT_MOC_LITERAL(28, 262, 10), // "outputFile"
QT_MOC_LITERAL(29, 273, 16), // "downloadRevision"
QT_MOC_LITERAL(30, 290, 4), // "revA"
QT_MOC_LITERAL(31, 295, 11), // "outputFileA"
QT_MOC_LITERAL(32, 307, 4), // "revB"
QT_MOC_LITERAL(33, 312, 11), // "outputFileB"
QT_MOC_LITERAL(34, 324, 4), // "diff"
QT_MOC_LITERAL(35, 329, 11), // "diffOptions"
QT_MOC_LITERAL(36, 341, 12), // "contextLines"
QT_MOC_LITERAL(37, 354, 6), // "format"
QT_MOC_LITERAL(38, 361, 4), // "edit"
QT_MOC_LITERAL(39, 366, 7), // "editors"
QT_MOC_LITERAL(40, 374, 7), // "history"
QT_MOC_LITERAL(41, 382, 6), // "import"
QT_MOC_LITERAL(42, 389, 10), // "ignoreList"
QT_MOC_LITERAL(43, 400, 7), // "comment"
QT_MOC_LITERAL(44, 408, 9), // "vendorTag"
QT_MOC_LITERAL(45, 418, 10), // "releaseTag"
QT_MOC_LITERAL(46, 429, 14), // "importAsBinary"
QT_MOC_LITERAL(47, 444, 19), // "useModificationTime"
QT_MOC_LITERAL(48, 464, 4), // "lock"
QT_MOC_LITERAL(49, 469, 3), // "log"
QT_MOC_LITERAL(50, 473, 5), // "login"
QT_MOC_LITERAL(51, 479, 6), // "logout"
QT_MOC_LITERAL(52, 486, 9), // "makePatch"
QT_MOC_LITERAL(53, 496, 10), // "moduleList"
QT_MOC_LITERAL(54, 507, 6), // "remove"
QT_MOC_LITERAL(55, 514, 11), // "removeWatch"
QT_MOC_LITERAL(56, 526, 4), // "rlog"
QT_MOC_LITERAL(57, 531, 14), // "simulateUpdate"
QT_MOC_LITERAL(58, 546, 10), // "createDirs"
QT_MOC_LITERAL(59, 557, 6), // "status"
QT_MOC_LITERAL(60, 564, 7), // "tagInfo"
QT_MOC_LITERAL(61, 572, 6), // "unedit"
QT_MOC_LITERAL(62, 579, 6), // "unlock"
QT_MOC_LITERAL(63, 586, 6), // "update"
QT_MOC_LITERAL(64, 593, 8), // "extraOpt"
QT_MOC_LITERAL(65, 602, 8), // "watchers"
QT_MOC_LITERAL(66, 611, 4) // "quit"

    },
    "CvsService\0add\0QDBusObjectPath\0\0files\0"
    "isBinary\0addWatch\0events\0annotate\0"
    "fileName\0revision\0checkout\0workingDir\0"
    "repository\0module\0tag\0pruneDirs\0alias\0"
    "exportOnly\0recursive\0commit\0commitMessage\0"
    "createRepository\0createTag\0branch\0"
    "force\0deleteTag\0downloadCvsIgnoreFile\0"
    "outputFile\0downloadRevision\0revA\0"
    "outputFileA\0revB\0outputFileB\0diff\0"
    "diffOptions\0contextLines\0format\0edit\0"
    "editors\0history\0import\0ignoreList\0"
    "comment\0vendorTag\0releaseTag\0"
    "importAsBinary\0useModificationTime\0"
    "lock\0log\0login\0logout\0makePatch\0"
    "moduleList\0remove\0removeWatch\0rlog\0"
    "simulateUpdate\0createDirs\0status\0"
    "tagInfo\0unedit\0unlock\0update\0extraOpt\0"
    "watchers\0quit"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CvsService[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      36,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,  194,    3, 0x0a /* Public */,
       6,    2,  199,    3, 0x0a /* Public */,
       8,    2,  204,    3, 0x0a /* Public */,
      11,    5,  209,    3, 0x0a /* Public */,
      11,    7,  220,    3, 0x0a /* Public */,
      11,    8,  235,    3, 0x0a /* Public */,
      20,    3,  252,    3, 0x0a /* Public */,
      22,    1,  259,    3, 0x0a /* Public */,
      23,    4,  262,    3, 0x0a /* Public */,
      26,    4,  271,    3, 0x0a /* Public */,
      27,    2,  280,    3, 0x0a /* Public */,
      29,    3,  285,    3, 0x0a /* Public */,
      29,    5,  292,    3, 0x0a /* Public */,
      34,    5,  303,    3, 0x0a /* Public */,
      34,    5,  314,    3, 0x0a /* Public */,
      38,    1,  325,    3, 0x0a /* Public */,
      39,    1,  328,    3, 0x0a /* Public */,
      40,    0,  331,    3, 0x0a /* Public */,
      41,    9,  332,    3, 0x0a /* Public */,
      48,    1,  351,    3, 0x0a /* Public */,
      49,    1,  354,    3, 0x0a /* Public */,
      50,    1,  357,    3, 0x0a /* Public */,
      51,    1,  360,    3, 0x0a /* Public */,
      52,    0,  363,    3, 0x0a /* Public */,
      52,    2,  364,    3, 0x0a /* Public */,
      53,    1,  369,    3, 0x0a /* Public */,
      54,    2,  372,    3, 0x0a /* Public */,
      55,    2,  377,    3, 0x0a /* Public */,
      56,    3,  382,    3, 0x0a /* Public */,
      57,    4,  389,    3, 0x0a /* Public */,
      59,    3,  398,    3, 0x0a /* Public */,
      61,    1,  405,    3, 0x0a /* Public */,
      62,    1,  408,    3, 0x0a /* Public */,
      63,    5,  411,    3, 0x0a /* Public */,
      65,    1,  422,    3, 0x0a /* Public */,
      66,    0,  425,    3, 0x0a /* Public */,

 // slots: parameters
    0x80000000 | 2, QMetaType::QStringList, QMetaType::Bool,    4,    5,
    0x80000000 | 2, QMetaType::QStringList, QMetaType::Int,    4,    7,
    0x80000000 | 2, QMetaType::QString, QMetaType::QString,    9,   10,
    0x80000000 | 2, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::Bool,   12,   13,   14,   15,   16,
    0x80000000 | 2, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::Bool, QMetaType::QString, QMetaType::Bool,   12,   13,   14,   15,   16,   17,   18,
    0x80000000 | 2, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::Bool, QMetaType::QString, QMetaType::Bool, QMetaType::Bool,   12,   13,   14,   15,   16,   17,   18,   19,
    0x80000000 | 2, QMetaType::QStringList, QMetaType::QString, QMetaType::Bool,    4,   21,   19,
    0x80000000 | 2, QMetaType::QString,   13,
    0x80000000 | 2, QMetaType::QStringList, QMetaType::QString, QMetaType::Bool, QMetaType::Bool,    4,   15,   24,   25,
    0x80000000 | 2, QMetaType::QStringList, QMetaType::QString, QMetaType::Bool, QMetaType::Bool,    4,   15,   24,   25,
    0x80000000 | 2, QMetaType::QString, QMetaType::QString,   13,   28,
    0x80000000 | 2, QMetaType::QString, QMetaType::QString, QMetaType::QString,    9,   10,   28,
    0x80000000 | 2, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString,    9,   30,   31,   32,   33,
    0x80000000 | 2, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::UInt,    9,   30,   32,   35,   36,
    0x80000000 | 2, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString,    9,   30,   32,   35,   37,
    0x80000000 | 2, QMetaType::QStringList,    4,
    0x80000000 | 2, QMetaType::QStringList,    4,
    0x80000000 | 2,
    0x80000000 | 2, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::Bool, QMetaType::Bool,   12,   13,   14,   42,   43,   44,   45,   46,   47,
    0x80000000 | 2, QMetaType::QStringList,    4,
    0x80000000 | 2, QMetaType::QString,    9,
    0x80000000 | 2, QMetaType::QString,   13,
    0x80000000 | 2, QMetaType::QString,   13,
    0x80000000 | 2,
    0x80000000 | 2, QMetaType::QString, QMetaType::QString,   35,   37,
    0x80000000 | 2, QMetaType::QString,   13,
    0x80000000 | 2, QMetaType::QStringList, QMetaType::Bool,    4,   19,
    0x80000000 | 2, QMetaType::QStringList, QMetaType::Int,    4,    7,
    0x80000000 | 2, QMetaType::QString, QMetaType::QString, QMetaType::Bool,   13,   14,   19,
    0x80000000 | 2, QMetaType::QStringList, QMetaType::Bool, QMetaType::Bool, QMetaType::Bool,    4,   19,   58,   16,
    0x80000000 | 2, QMetaType::QStringList, QMetaType::Bool, QMetaType::Bool,    4,   19,   60,
    0x80000000 | 2, QMetaType::QStringList,    4,
    0x80000000 | 2, QMetaType::QStringList,    4,
    0x80000000 | 2, QMetaType::QStringList, QMetaType::Bool, QMetaType::Bool, QMetaType::Bool, QMetaType::QString,    4,   19,   58,   16,   64,
    0x80000000 | 2, QMetaType::QStringList,    4,
    QMetaType::Void,

       0        // eod
};

void CvsService::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        CvsService *_t = static_cast<CvsService *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: { QDBusObjectPath _r = _t->add((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 1: { QDBusObjectPath _r = _t->addWatch((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusObjectPath _r = _t->annotate((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusObjectPath _r = _t->checkout((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusObjectPath _r = _t->checkout((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6])),(*reinterpret_cast< bool(*)>(_a[7])));
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusObjectPath _r = _t->checkout((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6])),(*reinterpret_cast< bool(*)>(_a[7])),(*reinterpret_cast< bool(*)>(_a[8])));
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusObjectPath _r = _t->commit((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusObjectPath _r = _t->createRepository((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusObjectPath _r = _t->createTag((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusObjectPath _r = _t->deleteTag((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusObjectPath _r = _t->downloadCvsIgnoreFile((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusObjectPath _r = _t->downloadRevision((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusObjectPath _r = _t->downloadRevision((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusObjectPath _r = _t->diff((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< uint(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusObjectPath _r = _t->diff((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusObjectPath _r = _t->edit((*reinterpret_cast< const QStringList(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusObjectPath _r = _t->editors((*reinterpret_cast< const QStringList(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusObjectPath _r = _t->history();
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusObjectPath _r = _t->import((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6])),(*reinterpret_cast< const QString(*)>(_a[7])),(*reinterpret_cast< bool(*)>(_a[8])),(*reinterpret_cast< bool(*)>(_a[9])));
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusObjectPath _r = _t->lock((*reinterpret_cast< const QStringList(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 20: { QDBusObjectPath _r = _t->log((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 21: { QDBusObjectPath _r = _t->login((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 22: { QDBusObjectPath _r = _t->logout((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 23: { QDBusObjectPath _r = _t->makePatch();
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 24: { QDBusObjectPath _r = _t->makePatch((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 25: { QDBusObjectPath _r = _t->moduleList((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 26: { QDBusObjectPath _r = _t->remove((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 27: { QDBusObjectPath _r = _t->removeWatch((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 28: { QDBusObjectPath _r = _t->rlog((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 29: { QDBusObjectPath _r = _t->simulateUpdate((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 30: { QDBusObjectPath _r = _t->status((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 31: { QDBusObjectPath _r = _t->unedit((*reinterpret_cast< const QStringList(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 32: { QDBusObjectPath _r = _t->unlock((*reinterpret_cast< const QStringList(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 33: { QDBusObjectPath _r = _t->update((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 34: { QDBusObjectPath _r = _t->watchers((*reinterpret_cast< const QStringList(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 35: _t->quit(); break;
        default: ;
        }
    }
}

const QMetaObject CvsService::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_CvsService.data,
      qt_meta_data_CvsService,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *CvsService::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CvsService::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CvsService.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int CvsService::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 36)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 36;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 36)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 36;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
