/****************************************************************************
** Meta object code from reading C++ file 'cvsjob.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/cervisia-17.08.3/cvsservice/cvsjob.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'cvsjob.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_CvsJob_t {
    QByteArrayData data[16];
    char stringdata0[174];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CvsJob_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CvsJob_t qt_meta_stringdata_CvsJob = {
    {
QT_MOC_LITERAL(0, 0, 6), // "CvsJob"
QT_MOC_LITERAL(1, 7, 9), // "jobExited"
QT_MOC_LITERAL(2, 17, 0), // ""
QT_MOC_LITERAL(3, 18, 10), // "normalExit"
QT_MOC_LITERAL(4, 29, 6), // "status"
QT_MOC_LITERAL(5, 36, 14), // "receivedStdout"
QT_MOC_LITERAL(6, 51, 6), // "buffer"
QT_MOC_LITERAL(7, 58, 14), // "receivedStderr"
QT_MOC_LITERAL(8, 73, 7), // "execute"
QT_MOC_LITERAL(9, 81, 6), // "cancel"
QT_MOC_LITERAL(10, 88, 9), // "isRunning"
QT_MOC_LITERAL(11, 98, 10), // "cvsCommand"
QT_MOC_LITERAL(12, 109, 6), // "output"
QT_MOC_LITERAL(13, 116, 19), // "slotProcessFinished"
QT_MOC_LITERAL(14, 136, 18), // "slotReceivedStdout"
QT_MOC_LITERAL(15, 155, 18) // "slotReceivedStderr"

    },
    "CvsJob\0jobExited\0\0normalExit\0status\0"
    "receivedStdout\0buffer\0receivedStderr\0"
    "execute\0cancel\0isRunning\0cvsCommand\0"
    "output\0slotProcessFinished\0"
    "slotReceivedStdout\0slotReceivedStderr"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CvsJob[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   69,    2, 0x06 /* Public */,
       5,    1,   74,    2, 0x06 /* Public */,
       7,    1,   77,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    0,   80,    2, 0x0a /* Public */,
       9,    0,   81,    2, 0x0a /* Public */,
      10,    0,   82,    2, 0x0a /* Public */,
      11,    0,   83,    2, 0x0a /* Public */,
      12,    0,   84,    2, 0x0a /* Public */,
      13,    0,   85,    2, 0x08 /* Private */,
      14,    0,   86,    2, 0x08 /* Private */,
      15,    0,   87,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool, QMetaType::Int,    3,    4,
    QMetaType::Void, QMetaType::QString,    6,
    QMetaType::Void, QMetaType::QString,    6,

 // slots: parameters
    QMetaType::Bool,
    QMetaType::Void,
    QMetaType::Bool,
    QMetaType::QString,
    QMetaType::QStringList,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void CvsJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        CvsJob *_t = static_cast<CvsJob *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->jobExited((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 1: _t->receivedStdout((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->receivedStderr((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: { bool _r = _t->execute();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->cancel(); break;
        case 5: { bool _r = _t->isRunning();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { QString _r = _t->cvsCommand();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 7: { QStringList _r = _t->output();
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->slotProcessFinished(); break;
        case 9: _t->slotReceivedStdout(); break;
        case 10: _t->slotReceivedStderr(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (CvsJob::*_t)(bool , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&CvsJob::jobExited)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (CvsJob::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&CvsJob::receivedStdout)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (CvsJob::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&CvsJob::receivedStderr)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject CvsJob::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_CvsJob.data,
      qt_meta_data_CvsJob,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *CvsJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CvsJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CvsJob.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int CvsJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void CvsJob::jobExited(bool _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void CvsJob::receivedStdout(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void CvsJob::receivedStderr(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
