/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -p cvsjobinterface /usr/src/ports/cervisia/cervisia-17.08.3-1.x86_64/src/cervisia-17.08.3/cvsservice/org.kde.cervisia5.cvsjob.xml
 *
 * qdbusxml2cpp is Copyright (C) 2017 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef CVSJOBINTERFACE_H
#define CVSJOBINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.cervisia5.cvsservice.cvsjob
 */
class OrgKdeCervisia5CvsserviceCvsjobInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.cervisia5.cvsservice.cvsjob"; }

public:
    OrgKdeCervisia5CvsserviceCvsjobInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeCervisia5CvsserviceCvsjobInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> cancel()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("cancel"), argumentList);
    }

    inline QDBusPendingReply<QString> cvsCommand()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("cvsCommand"), argumentList);
    }

    inline QDBusPendingReply<bool> execute()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("execute"), argumentList);
    }

    inline QDBusPendingReply<bool> isRunning()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("isRunning"), argumentList);
    }

    inline QDBusPendingReply<QStringList> output()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("output"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void jobExited(bool in0, int in1);
    void receivedStderr(const QString &in0);
    void receivedStdout(const QString &in0);
};

namespace org {
  namespace kde {
    namespace cervisia5 {
      namespace cvsservice {
        typedef ::OrgKdeCervisia5CvsserviceCvsjobInterface cvsjob;
      }
    }
  }
}
#endif
