/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -a protocolviewadaptor -i protocolview.h -l ProtocolView /usr/src/ports/cervisia/cervisia-17.08.3-1.x86_64/src/cervisia-17.08.3/org.kde.cervisia5.protocolview.xml
 *
 * qdbusxml2cpp is Copyright (C) 2017 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "protocolviewadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class ProtocolviewAdaptor
 */

ProtocolviewAdaptor::ProtocolviewAdaptor(ProtocolView *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

ProtocolviewAdaptor::~ProtocolviewAdaptor()
{
    // destructor
}

void ProtocolviewAdaptor::slotJobExited(bool normalExit, int exitStatus)
{
    // handle method call org.kde.cervisia5.protocolview.slotJobExited
    parent()->slotJobExited(normalExit, exitStatus);
}

void ProtocolviewAdaptor::slotReceivedOutput(const QString &buffer)
{
    // handle method call org.kde.cervisia5.protocolview.slotReceivedOutput
    parent()->slotReceivedOutput(buffer);
}


#include "protocolviewadaptor.moc"
