/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -a cvsjobadaptor -i cvsjob.h -l CvsJob /usr/src/ports/cervisia/cervisia-17.08.3-1.x86_64/src/cervisia-17.08.3/cvsservice/org.kde.cervisia5.cvsjob.xml
 *
 * qdbusxml2cpp is Copyright (C) 2017 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "cvsjobadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class CvsjobAdaptor
 */

CvsjobAdaptor::CvsjobAdaptor(CvsJob *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

CvsjobAdaptor::~CvsjobAdaptor()
{
    // destructor
}

void CvsjobAdaptor::cancel()
{
    // handle method call org.kde.cervisia5.cvsservice.cvsjob.cancel
    parent()->cancel();
}

QString CvsjobAdaptor::cvsCommand()
{
    // handle method call org.kde.cervisia5.cvsservice.cvsjob.cvsCommand
    return parent()->cvsCommand();
}

bool CvsjobAdaptor::execute()
{
    // handle method call org.kde.cervisia5.cvsservice.cvsjob.execute
    return parent()->execute();
}

bool CvsjobAdaptor::isRunning()
{
    // handle method call org.kde.cervisia5.cvsservice.cvsjob.isRunning
    return parent()->isRunning();
}

QStringList CvsjobAdaptor::output()
{
    // handle method call org.kde.cervisia5.cvsservice.cvsjob.output
    return parent()->output();
}


#include "cvsjobadaptor.moc"
