/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -p cvsjobinterface /usr/src/ports/cervisia/cervisia-17.08.3-1.x86_64/src/cervisia-17.08.3/cvsservice/org.kde.cervisia5.cvsjob.xml
 *
 * qdbusxml2cpp is Copyright (C) 2017 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#include "cvsjobinterface.h"

/*
 * Implementation of interface class OrgKdeCervisia5CvsserviceCvsjobInterface
 */

OrgKdeCervisia5CvsserviceCvsjobInterface::OrgKdeCervisia5CvsserviceCvsjobInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
    : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
{
}

OrgKdeCervisia5CvsserviceCvsjobInterface::~OrgKdeCervisia5CvsserviceCvsjobInterface()
{
}


#include "cvsjobinterface.moc"
