/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -a cvsloginjobadaptor -i cvsloginjob.h -l CvsLoginJob /usr/src/ports/cervisia/cervisia-17.08.3-1.x86_64/src/cervisia-17.08.3/cvsservice/org.kde.cervisia5.cvsloginjob.xml
 *
 * qdbusxml2cpp is Copyright (C) 2017 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "cvsloginjobadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class CvsloginjobAdaptor
 */

CvsloginjobAdaptor::CvsloginjobAdaptor(CvsLoginJob *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

CvsloginjobAdaptor::~CvsloginjobAdaptor()
{
    // destructor
}

bool CvsloginjobAdaptor::execute()
{
    // handle method call org.kde.cervisia5.cvsservice.cvsloginjob.execute
    return parent()->execute();
}

QStringList CvsloginjobAdaptor::output()
{
    // handle method call org.kde.cervisia5.cvsservice.cvsloginjob.output
    return parent()->output();
}


#include "cvsloginjobadaptor.moc"
