/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -p cvsserviceinterface /usr/src/ports/cervisia/cervisia-17.08.3-1.x86_64/src/cervisia-17.08.3/cvsservice/org.kde.cervisia5.cvsservice.xml
 *
 * qdbusxml2cpp is Copyright (C) 2017 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef CVSSERVICEINTERFACE_H
#define CVSSERVICEINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.cervisia5.cvsservice.cvsservice
 */
class OrgKdeCervisia5CvsserviceCvsserviceInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.cervisia5.cvsservice.cvsservice"; }

public:
    OrgKdeCervisia5CvsserviceCvsserviceInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeCervisia5CvsserviceCvsserviceInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<QDBusObjectPath> add(const QStringList &files, bool isBinary)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(files) << QVariant::fromValue(isBinary);
        return asyncCallWithArgumentList(QStringLiteral("add"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> addWatch(const QStringList &files, int events)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(files) << QVariant::fromValue(events);
        return asyncCallWithArgumentList(QStringLiteral("addWatch"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> annotate(const QString &fileName, const QString &revision)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(fileName) << QVariant::fromValue(revision);
        return asyncCallWithArgumentList(QStringLiteral("annotate"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> checkout(const QString &workingDir, const QString &repository, const QString &module, const QString &tag, bool pruneDirs, const QString &alias, bool exportOnly, bool recursive)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(workingDir) << QVariant::fromValue(repository) << QVariant::fromValue(module) << QVariant::fromValue(tag) << QVariant::fromValue(pruneDirs) << QVariant::fromValue(alias) << QVariant::fromValue(exportOnly) << QVariant::fromValue(recursive);
        return asyncCallWithArgumentList(QStringLiteral("checkout"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> checkout(const QString &workingDir, const QString &repository, const QString &module, const QString &tag, bool pruneDirs, const QString &alias, bool exportOnly)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(workingDir) << QVariant::fromValue(repository) << QVariant::fromValue(module) << QVariant::fromValue(tag) << QVariant::fromValue(pruneDirs) << QVariant::fromValue(alias) << QVariant::fromValue(exportOnly);
        return asyncCallWithArgumentList(QStringLiteral("checkout"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> checkout(const QString &workingDir, const QString &repository, const QString &module, const QString &tag, bool pruneDirs)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(workingDir) << QVariant::fromValue(repository) << QVariant::fromValue(module) << QVariant::fromValue(tag) << QVariant::fromValue(pruneDirs);
        return asyncCallWithArgumentList(QStringLiteral("checkout"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> commit(const QStringList &files, const QString &commitMessage, bool recursive)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(files) << QVariant::fromValue(commitMessage) << QVariant::fromValue(recursive);
        return asyncCallWithArgumentList(QStringLiteral("commit"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> createRepository(const QString &repository)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(repository);
        return asyncCallWithArgumentList(QStringLiteral("createRepository"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> createTag(const QStringList &files, const QString &tag, bool branch, bool force)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(files) << QVariant::fromValue(tag) << QVariant::fromValue(branch) << QVariant::fromValue(force);
        return asyncCallWithArgumentList(QStringLiteral("createTag"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> deleteTag(const QStringList &files, const QString &tag, bool branch, bool force)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(files) << QVariant::fromValue(tag) << QVariant::fromValue(branch) << QVariant::fromValue(force);
        return asyncCallWithArgumentList(QStringLiteral("deleteTag"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> diff(const QString &fileName, const QString &revA, const QString &revB, const QString &diffOptions, const QString &format)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(fileName) << QVariant::fromValue(revA) << QVariant::fromValue(revB) << QVariant::fromValue(diffOptions) << QVariant::fromValue(format);
        return asyncCallWithArgumentList(QStringLiteral("diff"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> diff(const QString &fileName, const QString &revA, const QString &revB, const QString &diffOptions, uint context)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(fileName) << QVariant::fromValue(revA) << QVariant::fromValue(revB) << QVariant::fromValue(diffOptions) << QVariant::fromValue(context);
        return asyncCallWithArgumentList(QStringLiteral("diff"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> downloadCvsIgnoreFile(const QString &repository, const QString &outputFile)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(repository) << QVariant::fromValue(outputFile);
        return asyncCallWithArgumentList(QStringLiteral("downloadCvsIgnoreFile"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> downloadRevision(const QString &fileName, const QString &revA, const QString &outputFileA, const QString &revB, const QString &outputFileB)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(fileName) << QVariant::fromValue(revA) << QVariant::fromValue(outputFileA) << QVariant::fromValue(revB) << QVariant::fromValue(outputFileB);
        return asyncCallWithArgumentList(QStringLiteral("downloadRevision"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> downloadRevision(const QString &fileName, const QString &revision, const QString &outputFile)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(fileName) << QVariant::fromValue(revision) << QVariant::fromValue(outputFile);
        return asyncCallWithArgumentList(QStringLiteral("downloadRevision"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> edit(const QStringList &files)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(files);
        return asyncCallWithArgumentList(QStringLiteral("edit"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> editors(const QStringList &files)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(files);
        return asyncCallWithArgumentList(QStringLiteral("editors"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> history()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("history"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> import(const QString &workingDir, const QString &repository, const QString &module, const QString &ignoreList, const QString &comment, const QString &vendorTag, const QString &releaseTag, bool importAsBinary, bool useModificationTime)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(workingDir) << QVariant::fromValue(repository) << QVariant::fromValue(module) << QVariant::fromValue(ignoreList) << QVariant::fromValue(comment) << QVariant::fromValue(vendorTag) << QVariant::fromValue(releaseTag) << QVariant::fromValue(importAsBinary) << QVariant::fromValue(useModificationTime);
        return asyncCallWithArgumentList(QStringLiteral("import"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> lock(const QStringList &files)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(files);
        return asyncCallWithArgumentList(QStringLiteral("lock"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> log(const QString &fileName)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(fileName);
        return asyncCallWithArgumentList(QStringLiteral("log"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> login(const QString &repository)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(repository);
        return asyncCallWithArgumentList(QStringLiteral("login"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> logout(const QString &repository)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(repository);
        return asyncCallWithArgumentList(QStringLiteral("logout"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> makePatch(const QString &diffOptions, const QString &format)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(diffOptions) << QVariant::fromValue(format);
        return asyncCallWithArgumentList(QStringLiteral("makePatch"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> makePatch()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("makePatch"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> moduleList(const QString &repository)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(repository);
        return asyncCallWithArgumentList(QStringLiteral("moduleList"), argumentList);
    }

    inline QDBusPendingReply<> quit()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("quit"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> remove(const QStringList &files, bool recursive)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(files) << QVariant::fromValue(recursive);
        return asyncCallWithArgumentList(QStringLiteral("remove"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> removeWatch(const QStringList &files, int events)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(files) << QVariant::fromValue(events);
        return asyncCallWithArgumentList(QStringLiteral("removeWatch"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> rlog(const QString &repository, const QString &module, bool recursive)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(repository) << QVariant::fromValue(module) << QVariant::fromValue(recursive);
        return asyncCallWithArgumentList(QStringLiteral("rlog"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> simulateUpdate(const QStringList &files, bool recursive, bool createDirs, bool pruneDirs)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(files) << QVariant::fromValue(recursive) << QVariant::fromValue(createDirs) << QVariant::fromValue(pruneDirs);
        return asyncCallWithArgumentList(QStringLiteral("simulateUpdate"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> status(const QStringList &files, bool recursive, bool tagInfo)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(files) << QVariant::fromValue(recursive) << QVariant::fromValue(tagInfo);
        return asyncCallWithArgumentList(QStringLiteral("status"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> unedit(const QStringList &files)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(files);
        return asyncCallWithArgumentList(QStringLiteral("unedit"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> unlock(const QStringList &files)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(files);
        return asyncCallWithArgumentList(QStringLiteral("unlock"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> update(const QStringList &files, bool recursive, bool createDirs, bool pruneDirs, const QString &extraOpt)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(files) << QVariant::fromValue(recursive) << QVariant::fromValue(createDirs) << QVariant::fromValue(pruneDirs) << QVariant::fromValue(extraOpt);
        return asyncCallWithArgumentList(QStringLiteral("update"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> watchers(const QStringList &files)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(files);
        return asyncCallWithArgumentList(QStringLiteral("watchers"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

namespace org {
  namespace kde {
    namespace cervisia5 {
      namespace cvsservice {
        typedef ::OrgKdeCervisia5CvsserviceCvsserviceInterface cvsservice;
      }
    }
  }
}
#endif
