/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -a cvsserviceadaptor -i cvsservice.h -l CvsService /usr/src/ports/cervisia/cervisia-17.08.3-1.x86_64/src/cervisia-17.08.3/cvsservice/org.kde.cervisia5.cvsservice.xml
 *
 * qdbusxml2cpp is Copyright (C) 2017 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "cvsserviceadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class CvsserviceAdaptor
 */

CvsserviceAdaptor::CvsserviceAdaptor(CvsService *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

CvsserviceAdaptor::~CvsserviceAdaptor()
{
    // destructor
}

QDBusObjectPath CvsserviceAdaptor::add(const QStringList &files, bool isBinary)
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.add
    return parent()->add(files, isBinary);
}

QDBusObjectPath CvsserviceAdaptor::addWatch(const QStringList &files, int events)
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.addWatch
    return parent()->addWatch(files, events);
}

QDBusObjectPath CvsserviceAdaptor::annotate(const QString &fileName, const QString &revision)
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.annotate
    return parent()->annotate(fileName, revision);
}

QDBusObjectPath CvsserviceAdaptor::checkout(const QString &workingDir, const QString &repository, const QString &module, const QString &tag, bool pruneDirs, const QString &alias, bool exportOnly, bool recursive)
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.checkout
    return parent()->checkout(workingDir, repository, module, tag, pruneDirs, alias, exportOnly, recursive);
}

QDBusObjectPath CvsserviceAdaptor::checkout(const QString &workingDir, const QString &repository, const QString &module, const QString &tag, bool pruneDirs, const QString &alias, bool exportOnly)
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.checkout
    return parent()->checkout(workingDir, repository, module, tag, pruneDirs, alias, exportOnly);
}

QDBusObjectPath CvsserviceAdaptor::checkout(const QString &workingDir, const QString &repository, const QString &module, const QString &tag, bool pruneDirs)
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.checkout
    return parent()->checkout(workingDir, repository, module, tag, pruneDirs);
}

QDBusObjectPath CvsserviceAdaptor::commit(const QStringList &files, const QString &commitMessage, bool recursive)
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.commit
    return parent()->commit(files, commitMessage, recursive);
}

QDBusObjectPath CvsserviceAdaptor::createRepository(const QString &repository)
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.createRepository
    return parent()->createRepository(repository);
}

QDBusObjectPath CvsserviceAdaptor::createTag(const QStringList &files, const QString &tag, bool branch, bool force)
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.createTag
    return parent()->createTag(files, tag, branch, force);
}

QDBusObjectPath CvsserviceAdaptor::deleteTag(const QStringList &files, const QString &tag, bool branch, bool force)
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.deleteTag
    return parent()->deleteTag(files, tag, branch, force);
}

QDBusObjectPath CvsserviceAdaptor::diff(const QString &fileName, const QString &revA, const QString &revB, const QString &diffOptions, const QString &format)
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.diff
    return parent()->diff(fileName, revA, revB, diffOptions, format);
}

QDBusObjectPath CvsserviceAdaptor::diff(const QString &fileName, const QString &revA, const QString &revB, const QString &diffOptions, uint context)
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.diff
    return parent()->diff(fileName, revA, revB, diffOptions, context);
}

QDBusObjectPath CvsserviceAdaptor::downloadCvsIgnoreFile(const QString &repository, const QString &outputFile)
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.downloadCvsIgnoreFile
    return parent()->downloadCvsIgnoreFile(repository, outputFile);
}

QDBusObjectPath CvsserviceAdaptor::downloadRevision(const QString &fileName, const QString &revA, const QString &outputFileA, const QString &revB, const QString &outputFileB)
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.downloadRevision
    return parent()->downloadRevision(fileName, revA, outputFileA, revB, outputFileB);
}

QDBusObjectPath CvsserviceAdaptor::downloadRevision(const QString &fileName, const QString &revision, const QString &outputFile)
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.downloadRevision
    return parent()->downloadRevision(fileName, revision, outputFile);
}

QDBusObjectPath CvsserviceAdaptor::edit(const QStringList &files)
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.edit
    return parent()->edit(files);
}

QDBusObjectPath CvsserviceAdaptor::editors(const QStringList &files)
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.editors
    return parent()->editors(files);
}

QDBusObjectPath CvsserviceAdaptor::history()
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.history
    return parent()->history();
}

QDBusObjectPath CvsserviceAdaptor::import(const QString &workingDir, const QString &repository, const QString &module, const QString &ignoreList, const QString &comment, const QString &vendorTag, const QString &releaseTag, bool importAsBinary, bool useModificationTime)
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.import
    return parent()->import(workingDir, repository, module, ignoreList, comment, vendorTag, releaseTag, importAsBinary, useModificationTime);
}

QDBusObjectPath CvsserviceAdaptor::lock(const QStringList &files)
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.lock
    return parent()->lock(files);
}

QDBusObjectPath CvsserviceAdaptor::log(const QString &fileName)
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.log
    return parent()->log(fileName);
}

QDBusObjectPath CvsserviceAdaptor::login(const QString &repository)
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.login
    return parent()->login(repository);
}

QDBusObjectPath CvsserviceAdaptor::logout(const QString &repository)
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.logout
    return parent()->logout(repository);
}

QDBusObjectPath CvsserviceAdaptor::makePatch(const QString &diffOptions, const QString &format)
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.makePatch
    return parent()->makePatch(diffOptions, format);
}

QDBusObjectPath CvsserviceAdaptor::makePatch()
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.makePatch
    return parent()->makePatch();
}

QDBusObjectPath CvsserviceAdaptor::moduleList(const QString &repository)
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.moduleList
    return parent()->moduleList(repository);
}

void CvsserviceAdaptor::quit()
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.quit
    parent()->quit();
}

QDBusObjectPath CvsserviceAdaptor::remove(const QStringList &files, bool recursive)
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.remove
    return parent()->remove(files, recursive);
}

QDBusObjectPath CvsserviceAdaptor::removeWatch(const QStringList &files, int events)
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.removeWatch
    return parent()->removeWatch(files, events);
}

QDBusObjectPath CvsserviceAdaptor::rlog(const QString &repository, const QString &module, bool recursive)
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.rlog
    return parent()->rlog(repository, module, recursive);
}

QDBusObjectPath CvsserviceAdaptor::simulateUpdate(const QStringList &files, bool recursive, bool createDirs, bool pruneDirs)
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.simulateUpdate
    return parent()->simulateUpdate(files, recursive, createDirs, pruneDirs);
}

QDBusObjectPath CvsserviceAdaptor::status(const QStringList &files, bool recursive, bool tagInfo)
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.status
    return parent()->status(files, recursive, tagInfo);
}

QDBusObjectPath CvsserviceAdaptor::unedit(const QStringList &files)
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.unedit
    return parent()->unedit(files);
}

QDBusObjectPath CvsserviceAdaptor::unlock(const QStringList &files)
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.unlock
    return parent()->unlock(files);
}

QDBusObjectPath CvsserviceAdaptor::update(const QStringList &files, bool recursive, bool createDirs, bool pruneDirs, const QString &extraOpt)
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.update
    return parent()->update(files, recursive, createDirs, pruneDirs, extraOpt);
}

QDBusObjectPath CvsserviceAdaptor::watchers(const QStringList &files)
{
    // handle method call org.kde.cervisia5.cvsservice.cvsservice.watchers
    return parent()->watchers(files);
}


#include "cvsserviceadaptor.moc"
