/****************************************************************************
** Meta object code from reading C++ file 'cervisiapart.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/cervisia-17.08.3/cervisiapart.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'cervisiapart.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_CervisiaPart_t {
    QByteArrayData data[63];
    char stringdata0[852];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CervisiaPart_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CervisiaPart_t qt_meta_stringdata_CervisiaPart = {
    {
QT_MOC_LITERAL(0, 0, 12), // "CervisiaPart"
QT_MOC_LITERAL(1, 13, 8), // "openFile"
QT_MOC_LITERAL(2, 22, 0), // ""
QT_MOC_LITERAL(3, 23, 7), // "openUrl"
QT_MOC_LITERAL(4, 31, 8), // "filename"
QT_MOC_LITERAL(5, 40, 9), // "openFiles"
QT_MOC_LITERAL(6, 50, 9), // "filenames"
QT_MOC_LITERAL(7, 60, 14), // "popupRequested"
QT_MOC_LITERAL(8, 75, 13), // "updateActions"
QT_MOC_LITERAL(9, 89, 8), // "slotOpen"
QT_MOC_LITERAL(10, 98, 11), // "slotResolve"
QT_MOC_LITERAL(11, 110, 10), // "slotStatus"
QT_MOC_LITERAL(12, 121, 10), // "slotUpdate"
QT_MOC_LITERAL(13, 132, 13), // "slotChangeLog"
QT_MOC_LITERAL(14, 146, 10), // "slotCommit"
QT_MOC_LITERAL(15, 157, 7), // "slotAdd"
QT_MOC_LITERAL(16, 165, 13), // "slotAddBinary"
QT_MOC_LITERAL(17, 179, 10), // "slotRemove"
QT_MOC_LITERAL(18, 190, 18), // "slotFileProperties"
QT_MOC_LITERAL(19, 209, 10), // "slotRevert"
QT_MOC_LITERAL(20, 220, 13), // "slotBrowseLog"
QT_MOC_LITERAL(21, 234, 12), // "slotAnnotate"
QT_MOC_LITERAL(22, 247, 12), // "slotDiffBase"
QT_MOC_LITERAL(23, 260, 12), // "slotDiffHead"
QT_MOC_LITERAL(24, 273, 14), // "slotLastChange"
QT_MOC_LITERAL(25, 288, 11), // "slotHistory"
QT_MOC_LITERAL(26, 300, 20), // "slotCreateRepository"
QT_MOC_LITERAL(27, 321, 12), // "slotCheckout"
QT_MOC_LITERAL(28, 334, 10), // "slotImport"
QT_MOC_LITERAL(29, 345, 16), // "slotRepositories"
QT_MOC_LITERAL(30, 362, 13), // "slotCreateTag"
QT_MOC_LITERAL(31, 376, 13), // "slotDeleteTag"
QT_MOC_LITERAL(32, 390, 15), // "slotUpdateToTag"
QT_MOC_LITERAL(33, 406, 16), // "slotUpdateToHead"
QT_MOC_LITERAL(34, 423, 9), // "slotMerge"
QT_MOC_LITERAL(35, 433, 12), // "slotAddWatch"
QT_MOC_LITERAL(36, 446, 15), // "slotRemoveWatch"
QT_MOC_LITERAL(37, 462, 16), // "slotShowWatchers"
QT_MOC_LITERAL(38, 479, 8), // "slotEdit"
QT_MOC_LITERAL(39, 488, 10), // "slotUnedit"
QT_MOC_LITERAL(40, 499, 15), // "slotShowEditors"
QT_MOC_LITERAL(41, 515, 8), // "slotLock"
QT_MOC_LITERAL(42, 524, 10), // "slotUnlock"
QT_MOC_LITERAL(43, 535, 13), // "slotMakePatch"
QT_MOC_LITERAL(44, 549, 14), // "slotCreateDirs"
QT_MOC_LITERAL(45, 564, 13), // "slotPruneDirs"
QT_MOC_LITERAL(46, 578, 13), // "slotHideFiles"
QT_MOC_LITERAL(47, 592, 16), // "slotHideUpToDate"
QT_MOC_LITERAL(48, 609, 15), // "slotHideRemoved"
QT_MOC_LITERAL(49, 625, 16), // "slotHideNotInCVS"
QT_MOC_LITERAL(50, 642, 24), // "slotHideEmptyDirectories"
QT_MOC_LITERAL(51, 667, 12), // "slotFoldTree"
QT_MOC_LITERAL(52, 680, 14), // "slotUnfoldTree"
QT_MOC_LITERAL(53, 695, 16), // "slotUnfoldFolder"
QT_MOC_LITERAL(54, 712, 19), // "slotUpdateRecursive"
QT_MOC_LITERAL(55, 732, 19), // "slotCommitRecursive"
QT_MOC_LITERAL(56, 752, 13), // "slotDoCVSEdit"
QT_MOC_LITERAL(57, 766, 13), // "slotConfigure"
QT_MOC_LITERAL(58, 780, 8), // "slotHelp"
QT_MOC_LITERAL(59, 789, 11), // "slotCVSInfo"
QT_MOC_LITERAL(60, 801, 15), // "slotJobFinished"
QT_MOC_LITERAL(61, 817, 15), // "slotOpenSandbox"
QT_MOC_LITERAL(62, 833, 18) // "slotSetupStatusBar"

    },
    "CervisiaPart\0openFile\0\0openUrl\0filename\0"
    "openFiles\0filenames\0popupRequested\0"
    "updateActions\0slotOpen\0slotResolve\0"
    "slotStatus\0slotUpdate\0slotChangeLog\0"
    "slotCommit\0slotAdd\0slotAddBinary\0"
    "slotRemove\0slotFileProperties\0slotRevert\0"
    "slotBrowseLog\0slotAnnotate\0slotDiffBase\0"
    "slotDiffHead\0slotLastChange\0slotHistory\0"
    "slotCreateRepository\0slotCheckout\0"
    "slotImport\0slotRepositories\0slotCreateTag\0"
    "slotDeleteTag\0slotUpdateToTag\0"
    "slotUpdateToHead\0slotMerge\0slotAddWatch\0"
    "slotRemoveWatch\0slotShowWatchers\0"
    "slotEdit\0slotUnedit\0slotShowEditors\0"
    "slotLock\0slotUnlock\0slotMakePatch\0"
    "slotCreateDirs\0slotPruneDirs\0slotHideFiles\0"
    "slotHideUpToDate\0slotHideRemoved\0"
    "slotHideNotInCVS\0slotHideEmptyDirectories\0"
    "slotFoldTree\0slotUnfoldTree\0"
    "slotUnfoldFolder\0slotUpdateRecursive\0"
    "slotCommitRecursive\0slotDoCVSEdit\0"
    "slotConfigure\0slotHelp\0slotCVSInfo\0"
    "slotJobFinished\0slotOpenSandbox\0"
    "slotSetupStatusBar"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CervisiaPart[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      60,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,  314,    2, 0x0a /* Public */,
       3,    1,  315,    2, 0x0a /* Public */,
       1,    1,  318,    2, 0x0a /* Public */,
       5,    1,  321,    2, 0x0a /* Public */,
       7,    1,  324,    2, 0x0a /* Public */,
       8,    0,  327,    2, 0x0a /* Public */,
       9,    0,  328,    2, 0x0a /* Public */,
      10,    0,  329,    2, 0x0a /* Public */,
      11,    0,  330,    2, 0x0a /* Public */,
      12,    0,  331,    2, 0x0a /* Public */,
      13,    0,  332,    2, 0x0a /* Public */,
      14,    0,  333,    2, 0x0a /* Public */,
      15,    0,  334,    2, 0x0a /* Public */,
      16,    0,  335,    2, 0x0a /* Public */,
      17,    0,  336,    2, 0x0a /* Public */,
      18,    0,  337,    2, 0x0a /* Public */,
      19,    0,  338,    2, 0x0a /* Public */,
      20,    0,  339,    2, 0x0a /* Public */,
      21,    0,  340,    2, 0x0a /* Public */,
      22,    0,  341,    2, 0x0a /* Public */,
      23,    0,  342,    2, 0x0a /* Public */,
      24,    0,  343,    2, 0x0a /* Public */,
      25,    0,  344,    2, 0x0a /* Public */,
      26,    0,  345,    2, 0x0a /* Public */,
      27,    0,  346,    2, 0x0a /* Public */,
      28,    0,  347,    2, 0x0a /* Public */,
      29,    0,  348,    2, 0x0a /* Public */,
      30,    0,  349,    2, 0x0a /* Public */,
      31,    0,  350,    2, 0x0a /* Public */,
      32,    0,  351,    2, 0x0a /* Public */,
      33,    0,  352,    2, 0x0a /* Public */,
      34,    0,  353,    2, 0x0a /* Public */,
      35,    0,  354,    2, 0x0a /* Public */,
      36,    0,  355,    2, 0x0a /* Public */,
      37,    0,  356,    2, 0x0a /* Public */,
      38,    0,  357,    2, 0x0a /* Public */,
      39,    0,  358,    2, 0x0a /* Public */,
      40,    0,  359,    2, 0x0a /* Public */,
      41,    0,  360,    2, 0x0a /* Public */,
      42,    0,  361,    2, 0x0a /* Public */,
      43,    0,  362,    2, 0x0a /* Public */,
      44,    0,  363,    2, 0x0a /* Public */,
      45,    0,  364,    2, 0x0a /* Public */,
      46,    0,  365,    2, 0x0a /* Public */,
      47,    0,  366,    2, 0x0a /* Public */,
      48,    0,  367,    2, 0x0a /* Public */,
      49,    0,  368,    2, 0x0a /* Public */,
      50,    0,  369,    2, 0x0a /* Public */,
      51,    0,  370,    2, 0x0a /* Public */,
      52,    0,  371,    2, 0x0a /* Public */,
      53,    0,  372,    2, 0x0a /* Public */,
      54,    0,  373,    2, 0x0a /* Public */,
      55,    0,  374,    2, 0x0a /* Public */,
      56,    0,  375,    2, 0x0a /* Public */,
      57,    0,  376,    2, 0x0a /* Public */,
      58,    0,  377,    2, 0x0a /* Public */,
      59,    0,  378,    2, 0x0a /* Public */,
      60,    0,  379,    2, 0x09 /* Protected */,
      61,    0,  380,    2, 0x08 /* Private */,
      62,    0,  381,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Bool,
    QMetaType::Bool, QMetaType::QUrl,    2,
    QMetaType::Void, QMetaType::QString,    4,
    QMetaType::Void, QMetaType::QStringList,    6,
    QMetaType::Void, QMetaType::QPoint,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void CervisiaPart::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        CervisiaPart *_t = static_cast<CervisiaPart *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: { bool _r = _t->openFile();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 1: { bool _r = _t->openUrl((*reinterpret_cast< const QUrl(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->openFile((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 3: _t->openFiles((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 4: _t->popupRequested((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 5: _t->updateActions(); break;
        case 6: _t->slotOpen(); break;
        case 7: _t->slotResolve(); break;
        case 8: _t->slotStatus(); break;
        case 9: _t->slotUpdate(); break;
        case 10: _t->slotChangeLog(); break;
        case 11: _t->slotCommit(); break;
        case 12: _t->slotAdd(); break;
        case 13: _t->slotAddBinary(); break;
        case 14: _t->slotRemove(); break;
        case 15: _t->slotFileProperties(); break;
        case 16: _t->slotRevert(); break;
        case 17: _t->slotBrowseLog(); break;
        case 18: _t->slotAnnotate(); break;
        case 19: _t->slotDiffBase(); break;
        case 20: _t->slotDiffHead(); break;
        case 21: _t->slotLastChange(); break;
        case 22: _t->slotHistory(); break;
        case 23: _t->slotCreateRepository(); break;
        case 24: _t->slotCheckout(); break;
        case 25: _t->slotImport(); break;
        case 26: _t->slotRepositories(); break;
        case 27: _t->slotCreateTag(); break;
        case 28: _t->slotDeleteTag(); break;
        case 29: _t->slotUpdateToTag(); break;
        case 30: _t->slotUpdateToHead(); break;
        case 31: _t->slotMerge(); break;
        case 32: _t->slotAddWatch(); break;
        case 33: _t->slotRemoveWatch(); break;
        case 34: _t->slotShowWatchers(); break;
        case 35: _t->slotEdit(); break;
        case 36: _t->slotUnedit(); break;
        case 37: _t->slotShowEditors(); break;
        case 38: _t->slotLock(); break;
        case 39: _t->slotUnlock(); break;
        case 40: _t->slotMakePatch(); break;
        case 41: _t->slotCreateDirs(); break;
        case 42: _t->slotPruneDirs(); break;
        case 43: _t->slotHideFiles(); break;
        case 44: _t->slotHideUpToDate(); break;
        case 45: _t->slotHideRemoved(); break;
        case 46: _t->slotHideNotInCVS(); break;
        case 47: _t->slotHideEmptyDirectories(); break;
        case 48: _t->slotFoldTree(); break;
        case 49: _t->slotUnfoldTree(); break;
        case 50: _t->slotUnfoldFolder(); break;
        case 51: _t->slotUpdateRecursive(); break;
        case 52: _t->slotCommitRecursive(); break;
        case 53: _t->slotDoCVSEdit(); break;
        case 54: _t->slotConfigure(); break;
        case 55: _t->slotHelp(); break;
        case 56: _t->slotCVSInfo(); break;
        case 57: _t->slotJobFinished(); break;
        case 58: _t->slotOpenSandbox(); break;
        case 59: _t->slotSetupStatusBar(); break;
        default: ;
        }
    }
}

const QMetaObject CervisiaPart::staticMetaObject = {
    { &KParts::ReadOnlyPart::staticMetaObject, qt_meta_stringdata_CervisiaPart.data,
      qt_meta_data_CervisiaPart,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *CervisiaPart::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CervisiaPart::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CervisiaPart.stringdata0))
        return static_cast<void*>(this);
    return KParts::ReadOnlyPart::qt_metacast(_clname);
}

int CervisiaPart::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KParts::ReadOnlyPart::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 60)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 60;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 60)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 60;
    }
    return _id;
}
struct qt_meta_stringdata_CervisiaBrowserExtension_t {
    QByteArrayData data[1];
    char stringdata0[25];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CervisiaBrowserExtension_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CervisiaBrowserExtension_t qt_meta_stringdata_CervisiaBrowserExtension = {
    {
QT_MOC_LITERAL(0, 0, 24) // "CervisiaBrowserExtension"

    },
    "CervisiaBrowserExtension"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CervisiaBrowserExtension[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void CervisiaBrowserExtension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject CervisiaBrowserExtension::staticMetaObject = {
    { &KParts::BrowserExtension::staticMetaObject, qt_meta_stringdata_CervisiaBrowserExtension.data,
      qt_meta_data_CervisiaBrowserExtension,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *CervisiaBrowserExtension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CervisiaBrowserExtension::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CervisiaBrowserExtension.stringdata0))
        return static_cast<void*>(this);
    return KParts::BrowserExtension::qt_metacast(_clname);
}

int CervisiaBrowserExtension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KParts::BrowserExtension::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
